==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/bem-ZM.pl <==
{
  am_pm_abbreviated => [
    "uluchelo",
    "akasuba"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "bem-ZM",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Palichimo",
    "Palichibuli",
    "Palichitatu",
    "Palichine",
    "Palichisano",
    "Pachibelushi",
    "Pa Mulungu"
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_format_wide => [
    "Palichimo",
    "Palichibuli",
    "Palichitatu",
    "Palichine",
    "Palichisano",
    "Pachibelushi",
    "Pa Mulungu"
  ],
  day_stand_alone_abbreviated => [
    "Palichimo",
    "Palichibuli",
    "Palichitatu",
    "Palichine",
    "Palichisano",
    "Pachibelushi",
    "Pa Mulungu"
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "Palichimo",
    "Palichibuli",
    "Palichitatu",
    "Palichine",
    "Palichisano",
    "Pachibelushi",
    "Pa Mulungu"
  ],
  era_abbreviated => [
    "BC",
    "AD"
  ],
  era_narrow => [
    "BC",
    "AD"
  ],
  era_wide => [
    "Before Yesu",
    "After Yesu"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%Y",
  glibc_datetime_format => "%a %d %b %Y %R %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Bemba",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Epr",
    "Mei",
    "Jun",
    "Jul",
    "Oga",
    "Sep",
    "Okt",
    "Nov",
    "Dis"
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "O",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "Januari",
    "Februari",
    "Machi",
    "Epreo",
    "Mei",
    "Juni",
    "Julai",
    "Ogasti",
    "Septemba",
    "Oktoba",
    "Novemba",
    "Disemba"
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Epr",
    "Mei",
    "Jun",
    "Jul",
    "Oga",
    "Sep",
    "Okt",
    "Nov",
    "Dis"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "O",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Januari",
    "Februari",
    "Machi",
    "Epreo",
    "Mei",
    "Juni",
    "Julai",
    "Ogasti",
    "Septemba",
    "Oktoba",
    "Novemba",
    "Disemba"
  ],
  name => "Bemba Zambia",
  native_language => "Ichibemba",
  native_name => "Ichibemba Zambia",
  native_script => undef,
  native_territory => "Zambia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  script => undef,
  territory => "Zambia",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.32.tar.gz: DateTime-Locale-1.32/share/bem-ZM.pl <==
{
  am_pm_abbreviated => [
    "uluchelo",
    "akasuba",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "bem-ZM",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Palichimo",
    "Palichibuli",
    "Palichitatu",
    "Palichine",
    "Palichisano",
    "Pachibelushi",
    "Pa Mulungu",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Palichimo",
    "Palichibuli",
    "Palichitatu",
    "Palichine",
    "Palichisano",
    "Pachibelushi",
    "Pa Mulungu",
  ],
  day_stand_alone_abbreviated => [
    "Palichimo",
    "Palichibuli",
    "Palichitatu",
    "Palichine",
    "Palichisano",
    "Pachibelushi",
    "Pa Mulungu",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Palichimo",
    "Palichibuli",
    "Palichitatu",
    "Palichine",
    "Palichisano",
    "Pachibelushi",
    "Pa Mulungu",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Before Yesu",
    "After Yesu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %R %Z",
  glibc_date_format => "%m/%d/%Y",
  glibc_datetime_format => "%a %d %b %Y %R",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Bemba",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Epr",
    "Mei",
    "Jun",
    "Jul",
    "Oga",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "O",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januari",
    "Februari",
    "Machi",
    "Epreo",
    "Mei",
    "Juni",
    "Julai",
    "Ogasti",
    "Septemba",
    "Oktoba",
    "Novemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Epr",
    "Mei",
    "Jun",
    "Jul",
    "Oga",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "O",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januari",
    "Februari",
    "Machi",
    "Epreo",
    "Mei",
    "Juni",
    "Julai",
    "Ogasti",
    "Septemba",
    "Oktoba",
    "Novemba",
    "Disemba",
  ],
  name => "Bemba Zambia",
  native_language => "Ichibemba",
  native_name => "Ichibemba Zambia",
  native_script => undef,
  native_territory => "Zambia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Zambia",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 39,
}
